pyLBM.stencil.Stencil
=====================

.. currentmodule:: pyLBM.stencil

.. autoclass:: Stencil

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Stencil.append
         Stencil.count
         Stencil.extend
         Stencil.get_all_velocities
         Stencil.get_stencil
         Stencil.get_symmetric
         Stencil.index
         Stencil.insert
         Stencil.is_symmetric
         Stencil.pop
         Stencil.remove
         Stencil.reverse
         Stencil.sort
         Stencil.visualize



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Stencil.num
         Stencil.unum
         Stencil.unvtot
         Stencil.uvx
         Stencil.uvy
         Stencil.uvz
         Stencil.vmax
         Stencil.vmin
         Stencil.vx
         Stencil.vy
         Stencil.vz

